# Develop in an editor

One of the main design goals for Panel was to make it seamless to work across development environments. This section will provide simple how-to guides on how to develop with Panel in an editor environment with either a Python or Markdown file.

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`code-square;2.5em;sd-mr-1 sd-animate-grow50` Develop apps in an editor
:link: editor
:link-type: doc

How to rapidly develop a Panel application in your favorite IDE or editor.
:::

:::{grid-item-card} {octicon}`bug;2.5em;sd-mr-1 sd-animate-grow50` Debug apps in an editor
:link: editor_debug
:link-type: doc

How to debug a Panel application in your favorite IDE or editor.
:::

:::{grid-item-card} {octicon}`gear;2.5em;sd-mr-1 sd-animate-grow50` Configure VS Code
:link: vscode_configure
:link-type: doc

How to configure VS Code to work efficiently with Panel
:::

:::{grid-item-card} {octicon}`markdown;2.5em;sd-mr-1 sd-animate-grow50` Write apps in Markdown
:link: markdown
:link-type: doc

How to write Panel applications inside Markdown files.
:::

::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

editor
markdown
```
